@@ -1,4 +1,5 @@
 import getopt
+from os import path
 import sys
 from .main import Main
 from .config import Config
@@ -14,8 +15,8 @@ def main():
     pass
     try:
         opts, args=getopt.gnu_getopt(sys.argv[1:],
-                            'ahf:r:lovm',
-                            ['help','add','modify','file=','remark=','remark_first','remark_last','only_remark','version','init_process','all'])
+                            'ahf:r:lovmd',
+                            ['help','add','modify','delete','delete_all','file=','remark=','remark_first','remark_last','only_remark','version','init_process','all'])
     except getopt.GetoptError as e:
         print("获取参数信息出错，错误提示：", e.msg)
         return
@@ -26,12 +27,6 @@ def main():
         argKey = opt[0]
         argVal = opt[1]
         if argKey == '-a' or argKey == '--add':
-            if file_path is None:
-                print('必须指定文件才能添加备注！')
-                return
-            if remark is None:
-                print('缺少备注信息！')
-                return
             main_process.add_remark(file_path, remark)
             return
         elif argKey == '-h' or argKey == '--help':
@@ -53,14 +48,14 @@ def main():
             main_process.list_all()
             return
         elif argKey == '--modify' or argKey == '-m':
-            if file_path is None:
-                print('必须指定文件才能修改备注！')
-                return
-            if remark is None:
-                print('缺少备注信息！')
-                return
             main_process.modify_remark(file_path, remark)
             return
+        elif argKey == '--delete' or argKey == '-d':
+            main_process.remove_remark(file_path)
+            return
+        elif argKey == '--delete_all':
+            main_process.remove_all()
+            return
         else:
             pass
     main_process.list_remarks()
